@@ -7,6 +7,7 @@
 """
 Contains handlers for the Mito API
 """
+from mitosheet.api.get_pivot_params import get_pivot_params
 from queue import Queue
 from threading import Thread
 
@@ -41,15 +42,15 @@ class API():
     -   Note that printing inside of a thread does not work properly! Use sys.stdout.flush() after the print statement.
         See here: https://stackoverflow.com/questions/18234469/python-multithreaded-print-statements-delayed-until-all-threads-complete-executi
     """
-    def __init__(self, wsc, send):
+    def __init__(self, steps_manager, send):
         self.api_queue = Queue(MAX_QUEUED_API_CALLS)
         # Note that we make the thread a daemon thread, which practically means that when
         # The process that starts this thread terminate, our API will terminate as well.
-        self.thread = Thread(target=handle_api_event_thread, args=(self.api_queue, wsc, send), daemon=True)
+        self.thread = Thread(target=handle_api_event_thread, args=(self.api_queue, steps_manager, send), daemon=True)
         self.thread.start()
 
         # Save some variables for ease
-        self.wsc = wsc
+        self.steps_manager = steps_manager
         self.send = send
 
     def process_new_api_call(self, event):
@@ -65,11 +66,11 @@ class API():
                 self.api_queue.get()
             self.api_queue.put(event)
         else:
-            handle_api_event(self.send, event, self.wsc)
+            handle_api_event(self.send, event, self.steps_manager)
 
 
 
-def handle_api_event_thread(queue, wsc, send):
+def handle_api_event_thread(queue, steps_manager, send):
     """
     This is the worker thread function, that actually is 
     responsible for handling at the API call events.
@@ -86,12 +87,12 @@ def handle_api_event_thread(queue, wsc, send):
         # because otherwise if an error is thrown, then the entire thread crashes, 
         # and then the API never works again
         try:
-            handle_api_event(send, event, wsc)
+            handle_api_event(send, event, steps_manager)
         except:
             # Log in error if it occurs
-            log_event_processed(event, wsc, failed=True)
+            log_event_processed(event, steps_manager, failed=True)
 
-def handle_api_event(send, event, wsc):
+def handle_api_event(send, event, steps_manager):
     """
     Handler for all API calls. Note that any response to the
     API must return the same ID that the incoming message contains,
@@ -108,15 +109,17 @@ def handle_api_event(send, event, wsc):
     elif event['type'] == 'import_summary':
         result = get_import_summary(event)
     elif event['type'] == 'get_dataframe_as_csv':
-        result = get_dataframe_as_csv(event, wsc)
+        result = get_dataframe_as_csv(event, steps_manager)
     elif event['type'] == 'get_graph':
-        result = get_graph(event, wsc)
+        result = get_graph(event, steps_manager)
     elif event['type'] == 'get_column_describe':
-        result = get_column_describe(event, wsc)
+        result = get_column_describe(event, steps_manager)
     elif event['type'] == 'get_column_dtype':
-        result = get_column_dtype(event, wsc)
+        result = get_column_dtype(event, steps_manager)
     elif event['type'] == 'get_saved_analysis_description':
-        result = get_saved_analysis_description(event, wsc)
+        result = get_saved_analysis_description(event, steps_manager)
+    elif event['type'] == 'get_pivot_params':
+        result = get_pivot_params(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
