@@ -107,49 +107,6 @@ def test_preserves_order_columns():
         'df1.insert(2, \'C\', 0)',
     ]
 
-def test_transpile_merge_all_columns():
-    df_one = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
-    df_two = pd.DataFrame(data={'A': [1], 'D': [100], 'E': [10]})
-    mito = create_mito_wrapper_dfs(df_one, df_two)
-
-    mito.merge_sheets(0, 'A', list(df_one.keys()), 1, 'A', list(df_two.keys()))
-
-    assert mito.transpiled_code == [
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
-        'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])'
-    ]
-
-def test_transpile_merge_some_all_columns():
-    df_one = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
-    df_two = pd.DataFrame(data={'A': [1], 'D': [100], 'E': [10]})
-    mito = create_mito_wrapper_dfs(df_one, df_two)
-
-    mito.merge_sheets(0, 'A', ['A', 'B'], 1, 'A', ['A', 'D'])
-
-    assert mito.transpiled_code == [
-        "temp_df = df2.drop_duplicates(subset='A')", 
-        "df1_tmp = df1.drop(['C'], axis=1)", 
-        "df2_tmp = temp_df.drop(['E'], axis=1)", 
-        "df3 = df1_tmp.merge(df2_tmp, left_on=['A'], right_on=['A'], how='left', suffixes=['_df1', '_df2'])"
-    ]
-
-def test_transpile_merge_all_columns_than_some_columns():
-    df_one = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
-    df_two = pd.DataFrame(data={'A': [1], 'D': [100], 'E': [10]})
-    mito = create_mito_wrapper_dfs(df_one, df_two)
-
-    mito.merge_sheets(0, 'A', list(df_one.keys()), 1, 'A', list(df_two.keys()))    
-    mito.merge_sheets(0, 'A', ['A', 'B'], 1, 'A', ['A', 'D'])
-
-    assert mito.transpiled_code == [
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
-        'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
-        "temp_df = df2.drop_duplicates(subset='A')", 
-        "df1_tmp = df1.drop(['C'], axis=1)", 
-        "df2_tmp = temp_df.drop(['E'], axis=1)", 
-        "df4 = df1_tmp.merge(df2_tmp, left_on=['A'], right_on=['A'], how='left', suffixes=['_df1', '_df2'])"
-    ]
-
 def test_transpile_delete_column():
     df1 = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
     mito = create_mito_wrapper_dfs(df1)
@@ -170,7 +127,7 @@ def test_removes_unedited_formulas_for_unedited_sheets():
     mito.set_formula('=C', 0, 'D', add_column=True)
     mito.set_formula('=C', 1, 'D', add_column=True)
 
-    mito.merge_sheets(0, 'A', ['A', 'B', 'C', 'D'], 1, 'A', ['A', 'B', 'C', 'D'])
+    mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C', 'D'], 1, 'A', ['A', 'B', 'C', 'D'])
 
     mito.set_formula('=C + 1', 1, 'D', add_column=True)
 
@@ -179,7 +136,7 @@ def test_removes_unedited_formulas_for_unedited_sheets():
         'df1[\'D\'] = df1[\'C\']',
         "df2.insert(3, 'D', 0)", 
         'df2[\'D\'] = df2[\'C\']',
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
+        'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
         'df2[\'D\'] = df2[\'C\'] + 1',
     ]
@@ -189,17 +146,17 @@ def test_mulitple_merges_no_formula_steps():
     df1 = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
     df2 = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
     mito = create_mito_wrapper_dfs(df1, df2)
-    mito.merge_sheets(0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
-    mito.merge_sheets(0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
-    mito.merge_sheets(0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
+    mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
+    mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
+    mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C'], 1, 'A', ['A', 'B', 'C'])
 
 
     assert mito.transpiled_code == [
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
+        'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
+        'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df4 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
+        'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df5 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])'
     ]
 
@@ -209,14 +166,14 @@ def test_optimization_with_other_edits():
     mito = create_mito_wrapper_dfs(df1, df2)
     mito.add_column(0, 'D')
     mito.set_formula('=A', 0, 'D')
-    mito.merge_sheets(0, 'A', ['A', 'B', 'C', 'D'], 1, 'A', ['A', 'B', 'C'])
+    mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C', 'D'], 1, 'A', ['A', 'B', 'C'])
     mito.add_column(0, 'AAA')
     mito.delete_column(0, 'AAA')
 
     assert mito.transpiled_code == [
         "df1.insert(3, 'D', 0)", 
         'df1[\'D\'] = df1[\'A\']',
-        'temp_df = df2.drop_duplicates(subset=\'A\')', 
+        'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
         'df1.insert(4, \'AAA\', 0)',
         'df1.drop(\'AAA\', axis=1, inplace=True)'
@@ -321,11 +278,11 @@ def test_transpile_merge_then_sort():
     df1 = pd.DataFrame(data={'Name': ["Aaron", "Nate"], 'Number': [123, 1]})
     df2 = pd.DataFrame(data={'Name': ["Aaron", "Nate"], 'Sign': ['Gemini', "Tarus"]})
     mito = create_mito_wrapper_dfs(df1, df2)
-    mito.merge_sheets(0, 'Name', list(df1.keys()), 1, 'Name', list(df2.keys()))
+    mito.merge_sheets('lookup', 0, 'Name', list(df1.keys()), 1, 'Name', list(df2.keys()))
     mito.sort(2, 'Number', 'ascending')
 
     assert mito.transpiled_code == [
-        'temp_df = df2.drop_duplicates(subset=\'Name\')',
+        'temp_df = df2.drop_duplicates(subset=\'Name\') # Remove duplicates so lookup merge only returns first match',
         'df3 = df1.merge(temp_df, left_on=[\'Name\'], right_on=[\'Name\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
         'df3 = df3.sort_values(by=\'Number\', ascending=True, na_position=\'first\')',
         'df3 = df3.reset_index(drop=True)'
