@@ -2,13 +2,13 @@
 Contains tests for the user.json file, making sure it upgrades properly,
 and that it can handle the various undefined versions of user.json that exist.
 """
-from datetime import datetime
 import os
 from copy import deepcopy
+import subprocess
 
 from mitosheet.utils import get_random_id
 from mitosheet._version import __version__
-from mitosheet.user.schemas import USER_JSON_VERSION_1, USER_JSON_VERSION_2
+from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY, USER_JSON_VERSION_1, USER_JSON_VERSION_2
 from mitosheet.user.db import USER_JSON_PATH, get_user_field
 from mitosheet.user import initialize_user
 from mitosheet.tests.user.conftest import check_user_json, write_fake_user_json, cleanup_files, today_str
@@ -219,4 +219,21 @@ def test_initialize_doesnt_overwrite_feedback():
     check_user_json(
         feedbacks=['A', 'B'],
         user_email=''
-    )
\ No newline at end of file
+    )
+
+def test_upgrades_version_2_to_version_3():
+    write_fake_user_json(
+        USER_JSON_VERSION_2,
+        static_user_id=get_random_id()
+    )
+
+    initialize_user()
+
+    check_user_json(
+        user_email=''
+    )
+
+def test_main_cli_turn_off_logging():
+    initialize_user()
+    out = subprocess.run(['python', '-m', 'mitosheet', 'turnofflogging'], capture_output=True)
+    assert get_user_field(UJ_MITOSHEET_TELEMETRY) == False
\ No newline at end of file
