@@ -7,15 +7,11 @@
 """
 Contains helpful utility functions
 """
-from copy import deepcopy
 import json
-from mitosheet.sheet_functions.types.utils import get_datetime_columns, get_float_columns, get_mito_type, get_timedelta_columns
+from mitosheet.sheet_functions.types.utils import get_datetime_columns, get_float_columns, get_timedelta_columns
 import pandas as pd
 import numpy as np
 import numbers
-from string import ascii_letters, digits
-import subprocess
-import os
 import uuid
 import re
 
@@ -24,6 +20,10 @@ def make_valid_header(column_header):
     Takes a header, and performs replaces against common characters
     to make the column_header valid!
     """
+    # If it's a tuple, we turn it into a string before continuing
+    if isinstance(column_header, tuple):
+        column_header = '_'.join([str(c) for c in column_header]).strip()
+
     # If it's just numbers, turn it into a string (with an underscore)
     if isinstance(column_header, numbers.Number):
         return str(column_header).replace('.', '_') + '_'
@@ -105,7 +105,7 @@ def get_header_renames(column_headers):
     return renames
 
 
-def dfs_to_json(dfs):
+def dfs_to_json(dfs) -> str:
     return json.dumps([df_to_json_dumpsable(df) for df in dfs])
 
 
@@ -151,61 +151,6 @@ def df_to_json_dumpsable(df: pd.DataFrame):
     return json_obj
 
 
-def does_sheet_index_exist_within_step(step, sheet_index):
-    """
-    Returns true iff a sheet_index exists within a step
-    """
-    return not (sheet_index < 0 or sheet_index >= len(step['dfs']))
-
-
-def add_df_to_step(step, new_df, df_name=None):
-    """
-    Helper function for adding a new dataframe to the current step!
-    """
-    # Update dfs by appending new df
-    step['dfs'].append(new_df)
-    # Also update the dataframe name
-    if df_name is None:
-        step['df_names'].append(f'df{len(step["df_names"]) + 1}')
-    else:
-        step['df_names'].append(df_name)
-    
-    # Update all the variables that depend on column_headers
-    column_headers = new_df.keys()
-    step['column_metatype'].append({column_header: 'value' for column_header in column_headers})
-    step['column_type'].append({column_header: get_mito_type(new_df[column_header]) for column_header in column_headers})
-    step['column_spreadsheet_code'].append({column_header: '' for column_header in column_headers})
-    step['column_python_code'].append({column_header: '' for column_header in column_headers})
-    step['column_evaluation_graph'].append({column_header: set() for column_header in column_headers})
-    step['column_filters'].append({column_header: {'operator':'And', 'filters': []} for column_header in column_headers})
-
-def create_new_step(prev_step, step_type, deep=True):
-    """
-    Creates a new step with new_step_id and step_type that starts
-    with the ending state of the previous step
-
-    We default to deep=True, which makes a deep copy of the dataframes
-    that are in the previous step. However, for steps that don't modify
-    any existing dataframes (e.g. imports, merges, pivots), we can 
-    set this to deep=False/
-    """
-    # The new step is a copy of the previous step, where we only take the data we need
-    # (which is the formula content only)
-    new_step = dict()
-
-    new_step['step_type'] = step_type
-    new_step['column_metatype'] = deepcopy(prev_step['column_metatype'])
-    new_step['column_type'] = deepcopy(prev_step['column_type'])
-    new_step['column_spreadsheet_code'] = deepcopy(prev_step['column_spreadsheet_code'])
-    new_step['column_python_code'] = deepcopy(prev_step['column_python_code'])
-    new_step['column_evaluation_graph'] = deepcopy(prev_step['column_evaluation_graph'])
-    new_step['column_filters'] = deepcopy(prev_step['column_filters'])
-    new_step['dfs'] = [df.copy(deep=deep) for df in prev_step['dfs']]
-    new_step['df_names'] = deepcopy(prev_step['df_names'])
-
-    return new_step
-
-
 def get_random_id():
     """
     Creates a new random ID for the user, which for any given user,
